@@ -1,14 +1,17 @@
 from __future__ import absolute_import
+from __future__ import unicode_literals
 
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from StringIO import StringIO
 import datetime as dt
 from decimal import Decimal
+from io import BytesIO
 from random import randint
 import os.path as osp
 
+try:
+    import openpyxl
+except ImportError:
+    openpyxl = None
+
 try:
     import xlrd
 except ImportError:
@@ -38,11 +41,6 @@ def _xlwt_required():
         raise ImportError('xlwt library is required to use this function or class')
 
 
-def _xlsx_required():
-    if xlsxwriter is None:
-        raise ImportError('xlsxwriter library is required to use this function or class')
-
-
 def http_headers(filename, randomize=True):
     basename, ext = osp.splitext(filename)
     if randomize:
@@ -67,7 +65,7 @@ def workbook_to_reader(xlwt_wb):
         convert xlwt Workbook instance to an xlrd instance for reading
     """
     _xlrd_required()
-    fh = StringIO()
+    fh = BytesIO()
     xlwt_wb.save(fh)
     # prep for reading
     fh.seek(0)
@@ -76,10 +74,10 @@ def workbook_to_reader(xlwt_wb):
 
 def xlsx_to_strio(xlsx_wb):
     """
-        convert xlwt Workbook instance to a stringio instance
+        convert xlwt Workbook instance to a BytesIO instance
     """
     _xlrd_required()
-    fh = StringIO()
+    fh = BytesIO()
     xlsx_wb.filename = fh
     xlsx_wb.close()
     # prep for reading
@@ -89,17 +87,13 @@ def xlsx_to_strio(xlsx_wb):
 
 def xlsx_to_reader(xlsx_wb):
     """
-        convert xlwt Workbook instance to an xlrd instance for reading
+        convert xlsxwriter Workbook instance to an xlrd instance for reading
     """
     fh = xlsx_to_strio(xlsx_wb)
     return xlrd.open_workbook(file_contents=fh.read())
 
 
 class Writer(object):
-    """
-        code from : http://panela.blog-city.com/pyexcelerator_xlwt_cheatsheet_create_native_excel_from_pu.htm
-    """
-
     STYLE_FACTORY = {}
     FONT_FACTORY = {}
 
@@ -176,7 +170,7 @@ class Writer(object):
             self.newrow()
 
     def newrow(self):
-        self.rownum +=1
+        self.rownum += 1
         self.colnum = 0
 
     def get_style(self, style):
@@ -187,7 +181,6 @@ class Writer(object):
         The values for keys are lists of tuples containing (attribute,
         value) pairs to set on model instances...
         """
-        #print "KEY", style
         style_key = tuple(style.items())
         s = self.STYLE_FACTORY.get(style_key, None)
         if s is None:
@@ -230,7 +223,36 @@ class Writer(object):
         return f
 
 
-class WriterX(object):
+class _OpenpyxlWriter:
+    def __init__(self, ws):
+        self.set_sheet(ws)
+
+    def set_sheet(self, ws):
+        self.ws = ws
+        # Openpyxl uses 1-based indexing for cells
+        self.rownum = 1
+        self.colnum = 1
+
+    def awrite(self, data, style=None, nextrow=False):
+        cell = self.ws.cell(column=self.colnum, row=self.rownum, value=data)
+        if style:
+            cell.style = style
+        self.colnum += 1
+        if nextrow:
+            self.nextrow()
+
+    def mwrite(self, *colvals, style=None, nextrow=False):
+        for val in colvals:
+            self.awrite(val, style)
+        if nextrow:
+            self.nextrow()
+
+    def nextrow(self):
+        self.rownum += 1
+        self.colnum = 1
+
+
+class _XlsxwriterWriter:
 
     def __init__(self, ws):
         self.set_sheet(ws)
@@ -246,9 +268,7 @@ class WriterX(object):
         if nextrow:
             self.nextrow()
 
-    def mwrite(self, *colvals, **kwargs):
-        style = kwargs.pop('style', None)
-        nextrow = kwargs.pop('nextrow', False)
+    def mwrite(self, *colvals, style=None, nextrow=False):
         for val in colvals:
             self.awrite(val, style)
         if nextrow:
@@ -259,6 +279,54 @@ class WriterX(object):
         self.colnum = 0
 
 
+class WriterX:
+    @property
+    def ws(self):
+        return self._writer.ws
+
+    @property
+    def rownum(self):
+        return self._writer.rownum
+
+    @rownum.setter
+    def rownum(self, value):
+        self._writer.rownum = value
+
+    @property
+    def colnum(self):
+        return self._writer.colnum
+
+    @colnum.setter
+    def colnum(self, value):
+        self._writer.colnum = value
+
+    def __init__(self, ws):
+        self._writer = None
+        if openpyxl:
+            from openpyxl.worksheet.worksheet import Worksheet
+            if isinstance(ws, Worksheet):
+                self._writer = _OpenpyxlWriter(ws)
+        if xlsxwriter:
+            from xlsxwriter.worksheet import Worksheet
+            if isinstance(ws, Worksheet):
+                self._writer = _XlsxwriterWriter(ws)
+
+        if not self._writer:
+            raise TypeError('worksheet type not supported')
+
+    def set_sheet(self, ws):
+        self._writer.set_sheet(ws)
+
+    def awrite(self, data, style=None, nextrow=False):
+        self._writer.awrite(data, style=style, nextrow=nextrow)
+
+    def mwrite(self, *colvals, style=None, nextrow=False):
+        self._writer.mwrite(*colvals, style=style, nextrow=nextrow)
+
+    def nextrow(self):
+        self._writer.nextrow()
+
+
 class XlwtHelper(Writer):
 
     @deprecate('XlwtHelper has been renamed to Writer')
@@ -266,26 +334,15 @@ class XlwtHelper(Writer):
         Writer.__init__(self, ws)
 
 
-class Reader(object):
-
+class _XlrdReader:
+    @deprecate('xlrd is no longer maintained, recommend switching to openpyxl')
     def __init__(self, xlrd_wb, sheetnum=0):
-        _xlrd_required()
         self.book = xlrd_wb
         self.sheetnum = sheetnum
         self.rownum = 0
         self.colnum = 0
         self.sheet = self.book.sheet_by_index(self.sheetnum)
 
-    @classmethod
-    def from_xlwt(cls, xlwt_wb):
-        wb = workbook_to_reader(xlwt_wb)
-        return cls(wb)
-
-    @classmethod
-    def from_xlsx(cls, xlsx_wb):
-        wb = xlsx_to_reader(xlsx_wb)
-        return cls(wb)
-
     def cell_value(self, is_date=False):
         try:
             return self.sheet.cell_value(self.rownum, self.colnum)
@@ -310,3 +367,92 @@ class Reader(object):
         self.rownum += 1
         self.colnum = 0
 
+
+class _OpenpyxlReader:
+    def __init__(self, openpyxl_wb, sheetnum=0):
+        self.book = openpyxl_wb
+        self.sheetnum = sheetnum
+        # Openpyxl uses 1-based indexing for cells
+        self.rownum = 1
+        self.colnum = 1
+        self.sheet = self.book[self.book.sheetnames[sheetnum]]
+
+    def cell_value(self, is_date=False):
+        try:
+            return self.sheet.cell(self.rownum, self.colnum).value
+        finally:
+            self.colnum += 1
+
+    def cell_date(self):
+        # Openpyxl automatically converts to date or datetime
+        value = self.cell_value()
+        if isinstance(value, dt.datetime):
+            return value.date()
+        elif isinstance(value, dt.date):
+            return value
+        else:
+            raise TypeError(f'{value}: not a date')
+
+    def cell_datetime(self):
+        # Openpyxl automatically converts to date or datetime
+        value = self.cell_value()
+        if isinstance(value, dt.datetime):
+            return value
+        elif isinstance(value, dt.date):
+            return dt.datetime(value.year, value.month, value.day)
+        else:
+            raise ValueError(f'{value}: not a datetime')
+
+    def cell_decimal(self):
+        value = self.cell_value()
+        return Decimal(value)
+
+    def next_row(self):
+        self.rownum += 1
+        self.colnum = 1
+
+
+class Reader(object):
+    def __init__(self, workbook, sheetnum=0):
+        self._reader = None
+        if openpyxl:
+            from openpyxl.workbook import Workbook
+            if isinstance(workbook, Workbook):
+                self._reader = _OpenpyxlReader(workbook, sheetnum=sheetnum)
+        if xlrd:
+            if xlsxwriter:
+                from xlsxwriter import Workbook
+                if isinstance(workbook, Workbook):
+                    self._reader = _XlrdReader(workbook, sheetnum=sheetnum)
+            if xlwt:
+                from xlwt.Workbook import Workbook
+                if isinstance(workbook, Workbook):
+                    self._reader = _XlrdReader(workbook, sheetnum=sheetnum)
+
+        if not self._reader:
+            raise TypeError('workbook type not supported')
+
+    @classmethod
+    def from_xlwt(cls, xlwt_wb):
+        wb = workbook_to_reader(xlwt_wb)
+        return _XlrdReader(wb)
+
+    @classmethod
+    def from_xlsx(cls, xlsx_wb):
+        wb = xlsx_to_reader(xlsx_wb)
+        return _XlrdReader(wb)
+
+    def cell_value(self, is_date=False):
+        return self._reader.cell_value(is_date=is_date)
+
+    def cell_date(self):
+        return self._reader.cell_date()
+
+    def cell_datetime(self):
+        return self._reader.cell_datetime()
+
+    def cell_decimal(self):
+        return self._reader.cell_decimal()
+
+    def next_row(self):
+        self._reader.next_row()
