@@ -1,17 +1,22 @@
 from __future__ import absolute_import
-from cStringIO import StringIO
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import datetime as dt
 import difflib
 import inspect
-import itertools
+from io import StringIO
 import logging
 import re
 import sys
 import warnings
 
-from blazeutils.decorators import decorator
 from blazeutils.log import clear_handlers_by_attr
 from blazeutils.helpers import Tee, prettifysql
+import six
+from six.moves import zip as izip
+import wrapt
+
 
 class LoggingHandler(logging.Handler):
     """ logging handler to check for expected logs when testing"""
@@ -47,6 +52,7 @@ class LoggingHandler(logging.Handler):
     def current(self):
         return self.messages['all'][self.all_index]
 
+
 def logging_handler(name=None, level=1):
     lh = LoggingHandler()
     lh.__blazeutils_testing__ = True
@@ -65,12 +71,15 @@ def logging_handler(name=None, level=1):
     logging.root.setLevel(level)
     return lh
 
+
 def clear_test_handlers():
     clear_handlers_by_attr('__blazeutils_testing__')
 
+
 class StdCapture(object):
 
     def __init__(self):
+        raise Exception('StdCapture wasn\'t easily converted to Python 3.  See comments in source.')
         self.orig_stdout = sys.stdout
         self.orig_stderr = sys.stderr
         self.clear()
@@ -85,6 +94,7 @@ class StdCapture(object):
         sys.stdout = self.orig_stdout
         sys.stderr = self.orig_stderr
 
+
 class ListIO(object):
     def __init__(self):
         self.reset()
@@ -108,6 +118,7 @@ class ListIO(object):
     def current(self):
         return self.contents[self.index]
 
+
 def emits_deprecation(*messages):
     """
         Decorate a test enforcing it emits the given DeprecationWarnings with
@@ -119,23 +130,27 @@ def emits_deprecation(*messages):
     # we need to make it loud for @emits_deprecation below
     warnings.filterwarnings("default", category=DeprecationWarning)
 
-    @decorator
-    def decorate(fn, *args, **kw):
+    @wrapt.decorator
+    def decorate(fn, instance, args, kw):
         if sys.version_info < (2, 6):
-            raise NotImplementedError('warnings.catch_warnings() is needed, but not available in Python versions < 2.6')
+            raise NotImplementedError('warnings.catch_warnings() is needed, but not available '
+                                      'in Python versions < 2.6')
         with warnings.catch_warnings(record=True) as wcm:
             retval = fn(*args, **kw)
             count = 0
-            for w, m in itertools.izip_longest(wcm, messages):
+            for w, m in izip(wcm, messages):
                 count += 1
                 assert m is not None, 'No message to match warning: %s' % w.message
                 assert w is not None, 'No warning to match message #%s: %s' % (count, m)
-                assert issubclass(w.category, DeprecationWarning), 'DeprecationWarning not emitted, got %s type instead' % w.category
-                assert re.search(m, str(w.message)), 'Message regex "%s" did not match "%s"' % (m, w.message)
+                assert issubclass(w.category, DeprecationWarning), \
+                    'DeprecationWarning not emitted, got %s type instead' % w.category
+                assert re.search(m, str(w.message)), \
+                    'Message regex "%s" did not match "%s"' % (m, w.message)
             return retval
     return decorate
 
-def raises(arg1, arg2=None, re_esc=True, **kwargs):
+
+def raises(arg1, arg2=None, re_esc=True, **kwargs):  # noqa
     """
         Decorate a test encorcing it emits the given Exception and message
         regex.
@@ -178,10 +193,10 @@ def raises(arg1, arg2=None, re_esc=True, **kwargs):
         exc_validator = arg1
         msgregex = None
         etype = None
-    elif isinstance(arg1, basestring):
+    elif isinstance(arg1, six.string_types):
         msgregex = arg1
         etype = arg2
-    elif isinstance(arg2, basestring):
+    elif isinstance(arg2, six.string_types):
         etype = arg1
         msgregex = arg2
     else:
@@ -191,27 +206,28 @@ def raises(arg1, arg2=None, re_esc=True, **kwargs):
     if re_esc and msgregex:
         msgregex = re.escape(msgregex)
 
-    @decorator
-    def decorate(fn, *args, **kw):
+    @wrapt.decorator
+    def decorate(fn, instance, args, kw):
         try:
             fn(*args, **kw)
             assert False, '@raises: no exception raised in %s()' % fn.__name__
-        except Exception, e:
+        except Exception as e:
             if exc_validator is not None and not exc_validator(e):
                 raise
             if etype is not None and not isinstance(e, etype):
                 raise
             if msgregex is not None and not re.search(msgregex, str(e)):
                 raise
-            for attrname, msg in kwargs.iteritems():
+            for attrname, msg in six.iteritems(kwargs):
                 if not hasattr(e, attrname):
-                    print '@raises: exception missing "{0}" attribute'.format(attrname)
+                    print('@raises: exception missing "{0}" attribute'.format(attrname))
                     raise
                 if getattr(e, attrname) != msg:
                     raise
 
     return decorate
 
+
 def assert_equal_sql(sql, correct_sql):
     sql_split = prettifysql(sql)
     correct_sql_split = prettifysql(correct_sql)
@@ -221,6 +237,7 @@ def assert_equal_sql(sql, correct_sql):
     failure_message = "%r != %r\n" % (sql, correct_sql) + sql_diff
     assert sql == correct_sql, failure_message
 
+
 def assert_equal_txt(txtblock, correct_txtblock):
     tb_split = txtblock.splitlines()
     ctb_split = correct_txtblock.splitlines()
@@ -230,6 +247,7 @@ def assert_equal_txt(txtblock, correct_txtblock):
         ))
         assert False, 'txt blocks not equal, diff follows: \n' + diff
 
+
 class FailLoader(object):
     """
         When an isntance is added to sys.meta_path, it will raise an ImportError
@@ -251,14 +269,17 @@ class FailLoader(object):
         for mod_name in self.modules:
             del sys.modules[mod_name]
 
+
 def mock_date_today(mock_obj, year, month=1, day=1):
     mock_obj.today.return_value = dt.date(year, month, day)
     mock_obj.side_effect = lambda *args, **kw: dt.date(*args, **kw)
 
+
 def mock_datetime_now(mock_obj, year, month=1, day=1, hour=0, min=0, sec=0):
     mock_obj.now.return_value = dt.datetime(year, month, day, hour, min, sec)
     mock_obj.side_effect = lambda *args, **kw: dt.datetime(*args, **kw)
 
+
 def mock_datetime_utcnow(mock_obj, year, month=1, day=1, hour=0, min=0, sec=0):
     mock_obj.utcnow.return_value = dt.datetime(year, month, day, hour, min, sec)
     mock_obj.side_effect = lambda *args, **kw: dt.datetime(*args, **kw)
